<?php
/**
 * Created by PhpStorm.
 * User: jderosa
 * Date: 20/04/20
 * Time: 11.57
 */

namespace FiloBlu\Rma\Block\Returns;
use Exception;
use Magento\ConfigurableProduct\Model\Product\Type\Configurable;
use Magento\Eav\Model\Config;
use Magento\Eav\Model\Form\Factory;
use Magento\Framework\App\ProductMetadataInterface;
use FiloBlu\Rma\Helper\EasyReturnHelper;
use Magento\Framework\Data\Collection\ModelFactory;
use Magento\Framework\Registry;
use Magento\Framework\View\Element\Template\Context;
use Magento\Rma\Helper\Data;
use Magento\Rma\Model\Item\FormFactory;
use Magento\Rma\Model\ItemFactory;
use Magento\Sales\Api\Data\OrderInterface;
use Magento\Sales\Model\Order\Address\Renderer;
use Magento\Store\Model\ScopeInterface;
use Throwable;

class Form extends \Magento\Rma\Block\Returns\Create
{
    /**
     * @var EasyReturnHelper
     */
    private $easyReturnHelper;

    /**
     * Form constructor.
     * @param Context $context
     * @param ModelFactory $modelFactory
     * @param Factory $formFactory
     * @param Config $eavConfig
     * @param ItemFactory $itemFactory
     * @param FormFactory $itemFormFactory
     * @param Data $rmaData
     * @param Registry $registry
     * @param Renderer $addressRenderer
     * @param EasyReturnHelper $easyReturnHelper
     * @param array $data
     */
    public function __construct(
        \Magento\Framework\View\Element\Template\Context $context,
        \Magento\Framework\Data\Collection\ModelFactory $modelFactory,
        \Magento\Eav\Model\Form\Factory $formFactory,
        \Magento\Eav\Model\Config $eavConfig,
        \Magento\Rma\Model\ItemFactory $itemFactory,
        \Magento\Rma\Model\Item\FormFactory $itemFormFactory,
        \Magento\Rma\Helper\Data $rmaData,
        \Magento\Framework\Registry $registry,
        \Magento\Sales\Model\Order\Address\Renderer $addressRenderer,
        EasyReturnHelper $easyReturnHelper,
        array $data = [])
    {
        parent::__construct($context, $modelFactory, $formFactory, $eavConfig, $itemFactory, $itemFormFactory, $rmaData, $registry, $addressRenderer, $data);
        $this->easyReturnHelper = $easyReturnHelper;
    }


    /**
     * @param null $storeId
     * @return bool
     */
    public function isRegionRequired(OrderInterface $order ){
        $storeId = $this->_storeManager->getStore()->getId();
        $country = $this->_scopeConfig->getValue('general/region/state_required', ScopeInterface::SCOPE_STORE, $storeId) ?? '';
        $myCountry = $order->getShippingAddress()->getCountryId();

        if ($country != ''){
            if (in_array($myCountry, explode(',', $country))){
                return true ;
            }
        }
        return false;
    }

    /**
     * @return bool
     */
    public function getIsEasyReturnEnabled(){
        try{
            return $this->easyReturnHelper->isEasyReturnEnabled($this->_storeManager->getStore()->getId());
        }catch (\Exception $e){
            $this->_logger->critical($e->getMessage());
            return false;
        }catch (\Throwable $t){
            $this->_logger->critical($t->getMessage());
            return false;
        }
    }


}